@@ -181,7 +181,7 @@ class Bot:
                 if callable(response):
                     result = response(self, msg, re.search(regex, msg.data.content))
                     if type(result) == str:
-                        self.send_msg(result, parent = msg)
+                        self.send_msg(msgString = result, parent = msg)
                     elif type(result) == dict:
                         for send, nick in result.items():
                             self.set_nick(nick)
